/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/

/******************************************************************************
* File Name : opbt.c
* Version : 1.21
* Device(s) : RH850/U2x
* Description : This is the main tutorial code.
*******************************************************************************
* History : DD.MM.YYYY Version Description
*         : 15.10.2018 1.00 First Release
*         : 12.11.2019 1.10 Added structures for bit settings
*         : 08.11.2021 1.21 iSYSTEM/TASKING extensions for BPA0/1
******************************************************************************/

#define uses_bits

#define U2A_OPTB00  0x3FF30010        // Default setting
#define U2A_OPTB01  0xF0FB0000        // Default setting
#define U2A_OPTB02  0xFFFFFFFF        // Default setting
#define U2A_OPTB03  0xF1FFFEFC        // Default except operating mode set to "normal operating mode"
#define U2A_OPTB04  0x0C0C0C0F        // Default setting
#define U2A_OPTB06  0xFFFF0FC3        // Default setting
#define U2A_OPTB07  0xFFFFFFFF        // Default setting
#define U2A_OPTB08  0xFFFFFFFE        // Default setting
#define U2A_OPTB09  0xFFF1FFFF        // Default setting
#define U2A_OPTB10  0xFBFD288E        // Default setting
#define U2A_OPTB11  0xFFFFFFFF        // Default setting
#define U2A_OPTB12  0xFFFFFFFD        // Default setting
#define U2A_OPTB13  0xFFFFFFFF        // Default setting
//#define U2A_OPTB14  0x00000002        // Default setting for the U2A-EVA
#define U2A_OPTB14  0x00000192        // Default setting for the U2A16 or U2A8
#define U2A_OPTB16  0x6FFFFFFF        // Default setting
#define U2A_OPTB17  0xFFFFFFFF        // Default setting
#define U2A_OPTB18  0xFFFFFFFF        // Default setting
#define U2A_OPTB19  0xFFFFFFFF        // Default setting
#define U2A_OPTB20  ~U2A_OPTB16|0x7088FF00  // Inverted value of U2A_OPTB16, set reserved bits at 8-15,19,23,28-30  to default
#define U2A_OPTB21  ~U2A_OPTB17|0x000000CC  // Inverted value of U2A_OPTB17, set reserved bits at 2,3,6,7       to default
#define U2A_OPTB22  ~U2A_OPTB18|0xC000C000  // Inverted value of U2A_OPTB18, set reserved bits at 14,15,30,31     to default
#define U2A_OPTB23  ~U2A_OPTB19|0xFFFFC000  // Inverted value of U2A_OPTB19, set reserved bits at 14-31       to default

/////////////////////////////////////////////////////////////////////////////////
// Configuration Setting Area (Option Bytes)
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".OPBT"
// 0xF1FF7EFC
const unsigned long opbt[64] =
{
  0x00000000,   // H'FF321380 Reset Vector (PE0)
  0x00000000,   // H'FF321384 Reset Vector (PE1)
  0x00800000,   // H'FF321388 Reset Vector (PE2)
  0x00800000,   // H'FF32138C Reset Vector (PE3)
  0xFFFFFFFF,   // H'FF321390 Reserved
  0xFFFFFFFF,   // H'FF321394 Reserved
  0xFFFFFFFF,   // H'FF321398 Reserved
  0xFFFFFFFF,   // H'FF32139C Reserved

// OPBT0 (0xFF3213A0): WDTBA configuration
#ifdef uses_bits
    0      << 31 |    // OPWRUNA    WDTBA trigger start mode: 0=software, 1=default
    0      << 30 |    // OPWDWMSA   WDTBA open windows size: 0=set by WDTBAWS, 1=set by WDTBWOST
    7      << 27 |    // OPWDOVFA   WDTBA overflow interval: 0=2^9, ....., 7=2^16
    1      << 26 |    // OPWDINTA   WDTBATIT configuration: 0=disabled, 1=enabled
    1      << 25 |    // * reserved *
    3      << 23 |    // OPWDWSA    WDTBA open window period: 0=25%, 1=50%, 2=75% ,3=100%
    14     << 19 |    // * reserved *
    0      << 18 |    // OPWDVACA   trigger register: 0=WDTBAWDTE (fixed), 1=WDTBAEVAC (variable)
    1      << 17 |    // * reserved *
    1      << 16 |    // OPWDENA    WDTBA enable: 0=disbale, 1=enable
    16     << 0,      // OPWDWOSTA  WDTBA open window start time: 2^0 .... 2^15
#else
    U2A_OPTB00,
#endif

// OPBT1 (0xFF3213A4): WDTB0-3 configuration
#ifdef uses_bits
    15     << 28 |    // * reserved *
    0      << 27 |    // OPWDRUN3   WDTB3 trigger start mode: 0=software, 1=default
    0      << 26 |    // OPWDRUN2   WDTB2 trigger start mode: 0=software, 1=default
    0      << 25 |    // OPWDRUN1   WDTB1 trigger start mode: 0=software, 1=default
    0      << 24 |    // OPWDRUN0   WDTB0 trigger start mode: 0=software, 1=default
    1      << 23 |    // * reserved *
    7      << 20 |    // OPWDOVF    WDTBn overflow interval: 0=2^9, ....., 7=2^16
    1      << 19 |    // * reserved *
    0      << 18 |    // OPWDVAC    WDTBn trigger register: 0=WDTBAWDTE (fixed), 1=WDTBAEVAC (variable)
    3      << 16 |    // * reserved *
    0      << 0,      // OPWDWWISA  WDTB Interrupt Output Timing: 2^0 .... 2^15
#else
    U2A_OPTB01,
#endif

// OPBT2 (0xFF3213A8):
    U2A_OPTB02,

// OPBT3 (FF3213AC): PE1-3 configuration, BIST configuration
#ifdef uses_bits
    15     << 28 |    // * reserved *
    0      << 27 |    // PE3_DISABLE: 0=enable, 1=disable
    0      << 26 |    // PE2_DISABLE: 0=enable, 1=disable
    0      << 25 |    // PE1_DISABLE: 0=enable, 1=disable
    0x1FF  << 16 |    // * reserved *
    1      << 15 |    // HWBIST:    Power-on BIST: 0=disable, 1=enable
    7      << 12 |    // * reserved *
    3      << 10 |    // TESTSET:   0:n.a. 1: LBIST, 2: MBIST, 3: LBIST and MBIST
    2      << 8  |    // LBISTSEL:  Power-on LBIST scenario: 0=#1, 1=#2, 2=#3, 3=n.a.
    0x3F   << 2  |    // * reserved *
    0      << 1  |    // STMSEL1:   Operating mode and startup area OPERATING MODE set to "normal operating mode"
    0      << 0,      // STMSEL0:   Operating mode and startup area
#else
    U2A_OPTB03,
#endif

// OPBT4 (0xFF3213B0): VMON configuration
#ifdef uses_bits
    0      << 30 |    // ISOVDDFLTW
    0      << 28 |    // ISOVDDCLKSEL
    1      << 27 |    // ISOVDDFLTEN
    1      << 26 |    // * reserved *
    0      << 25 |    // ISOVDDHDE: ISOVDD high-voltage detection enable.
    0      << 24 |    // ISOVDDLDE: ISOVDD low-voltage detection enable.
    0      << 22 |    // VCCFLTW
    0      << 20 |    // VCCCLKSEL
    1      << 19 |    // VCCFLTEN
    1      << 18 |    // * reserved *
    0      << 17 |    // VCCHDE:    VCC high-voltage detection enable.
    0      << 16 |    // VCCLDE:    VCC high-voltage detection enable.
    0      << 14 |    // E0VCCFLTW
    0      << 12 |    // E0VCCCLKSEL
    1      << 11 |    // E0VCCFLTEN
    1      << 10 |    // * reserved *
    0      << 9  |    // E0VCCHDE
    0      << 8  |    // E0VCCLDE
    0      << 6  |    // AWOVDDFLTW
    0      << 4  |    // AWOVDDCLKSEL
    1      << 3  |    // AWOVDDFLTEN
    1      << 2  |    // DSDETEN
    3      << 0,      // * reserved *
#else
    U2A_OPTB04,
#endif


// (0xFF3213B4): * reserved *
    0xFFFFFFFF,

// OPT6 (0xFF3213B8): RAM initialization mode
#ifdef uses_bits
    0xFFFF0<< 12 |    // * reserved *
    3      << 10 |    // STAC_DTSRAM: 0&2=disabled, 1=n.a., 3=enabled
    3      << 8  |    // STAC_DPRAM:  0&2=disabled, 1=n.a., 3=enabled
    0x30   << 2  |    // * reserved *
    3      << 0,      // STAC_GTM:  0&2=disabled, 1=n.a., 3=enabled
#else
    U2A_OPTB06,
#endif

// OPT7 (0xFF3213BC):  RAM initialization mode
#ifdef uses_bits
    0x3FF  << 22 |    // * reserved *
    3      << 20 |    // STAC_MMCA: 0&2=disabled, 1=n.a., 3=enabled
    3      << 18 |    // STAC_MPSI9:  0&2=disabled, 1=n.a., 3=enabled
    3      << 16 |    // STAC_MSPI8:  0&2=disabled, 1=n.a., 3=enabled
    0      << 14 |    // STAC_MSPI7:  0&2=disabled, 1=n.a., 3=enabled
    3      << 12 |    // STAC_MSPI6:  0&2=disabled, 1=n.a., 3=enabled
    0      << 10 |    // STAC_MSPI5:  0&2=disabled, 1=n.a., 3=enabled
    3      << 8  |    // STAC_MSPI4:  0&2=disabled, 1=n.a., 3=enabled
    0      << 6  |    // STAC_MSPI3:  0&2=disabled, 1=n.a., 3=enabled
    3      << 4  |    // STAC_MSPI2:  0&2=disabled, 1=n.a., 3=enabled
    0      << 2  |    // STAC_MSPI1:  0&2=disabled, 1=n.a., 3=enabled
    3      << 0,      // STAC_MSPI0:  0&2=disabled, 1=n.a., 3=enabled
#else
    U2A_OPTB07,
#endif

// OPT8 (0xFF3213C0): Ethernet xII selection
#ifdef uses_bits
    0xF    << 28 |    // * reserved *
    1      << 27 |    // ETN_SGMII_SEL ETNB1: 0=MII, 1=SGMII
    1      << 26 |    // * reserved *
    1      << 25 |    // ETN_RMII_SEL: ETNB0: 0=MII, 1=RMII
    0x1FFFFFE<< 0,    // * reserved *
#else
    U2A_OPTB08,
#endif

// OPT9 (0xFF3213C4):
#ifdef uses_bits
    0xFFF  << 20 |    // * reserved *
    0      << 19 |    // PE3_LSDC_DIS:  PE3 LSDC: 0=enable, 1=disable
    0      << 18 |    // PE2_LSDC_DIS:  PE2 LSDC: 0=enable, 1=disable
    0      << 17 |    // PE1_LSDC_DIS:  PE1 LSDC: 0=enable, 1=disable
    0x1F   << 12 |    // Reserved
    1      << 11 |    // PE3_HVE:     PE3 Hypervisor: 0=disable, 1=enable
    1      << 10 |    // PE2_HVE:     PE2 Hypervisor: 0=disable, 1=enable
    1      << 9  |    // PE1_HVE:     PE1 Hypervisor: 0=disable, 1=enable
    1      << 8  |    // PE0_HVE:     PE0 Hypervisor: 0=disable, 1=enable
    0x7F   << 1  |    // Reserved
    1      << 0,      // EVA_PRD_EMU:   EmuDevice mode: 0=U2A8, 1=U2A16
#else
    U2A_OPTB09,
#endif

// OPT10 (0xFF3213C8): MainOSC configuration
#ifdef uses_bits
    7      << 29 |    // Reserved
    1      << 28 |    // MOSC_EXCLKINPUT: MainOSC input: 0=direct clock, 1=oscillator
    1      << 27 |    // Reserved
    3      << 24 |    // MOSC_FREQ:   MainOSC frequency: 0=16MHz, 1=20MHz, 2=24MHz, 3=40MHz, other=n.a.
    1      << 23 |    // Reserved:
    7      << 20 |    // MOSC_AMPSEL_A: OSC drivability during oscillation destabilization.
    1      << 19 |    // Reserved
    5      << 16 |    // MOSC_AMPSEL_B: OSC drivability during oscillation stabilization.
    2      << 12 |    // MOSC_CAP_SEL:  internal capacitance
    1      << 11 |    // Reserved
    0      << 8  |    // MOSC_RD_SEL_A: Damping resistor during oscillation destabilization
    1      << 7  |    // Reserved
    0      << 4  |    // MOSC_RD_SEL_B: Damping resistor during oscillation stabilization
    3      << 2  |    // Reserved
    1      << 1  |    // MOSC_SHTSTBY_A:  OSC drivability during oscillation destabilization.
    0      << 0,      // MOSC_SHTSTBY_B:  OSC drivability during oscillation stabilization.
#else
    U2A_OPTB10,
#endif

// OPT11 (0xFF3213CC):
#ifdef uses_bits
    3      << 30 |    // CKDIVMD
    1      << 29 |    // * reserved *
    1      << 28 |    // STARTUPPLL
    0xFFFFFFF<<0,     // * reserved *
#else
    U2A_OPTB11,       // H'FF3213CC OBT11
#endif

// OPT12 (0xFF3213D0):
#ifdef uses_bits
    0x3FFFFFFF<<2 |   // * reserved *
    1      << 0,      // MAPMODE:     Code flash memory mapping:  0=Double Map, 1=Single Map, 2-3=n.a.

#else
    U2A_OPTB12,       // H'FF3213D0 OPBT12
#endif

// OPT13 (0xFF3213D4): Double map mode switching of cluster 1/0
#ifdef uses_bits
    0x3FFFFFFF<<2 |   // * reserved *
    1   << 1  |       // DBMAPSW1:    0= Bank D is mapped, 1= Bank C is mapped
    1   << 0,         // DBMAPSW0:    0= Bank B is mapped, 1= Bank A is mapped
#else
    U2A_OPTB13,     // H'FF3213D4 OPBT13
#endif

// OPT14 (0xFF3213D8): SGMII configuration
#if 0 //def uses_bits
    0   << 11 |   // * reserved *
    0   << 10 |   // SGMII_POL_INV_TX:TX_DATAP/TX_DATAN polarity: 0=inverted, 1=non-inverted
    0   << 9  |   // SGMII_POL_INV_RX:RX_DATAP/RX_DATAN polarity: 0=inverted, 1=non-inverted
    0   << 3  |   // * reserved *
    0   << 2  |   // SGMIITISAMPEN: SGMII output amplitude: 0=300mVpp (600mVppd), 1=600mVpp (1200mVppd)
    2   << 0,     // SGMII_RISRCREN:  SGMII receiver termination: 0=High-Z, 1=n.a., 2=50Ohm+50Ohm, 3=50Ohm to Vcm
#else
    U2A_OPTB14,   // H'FF3213D8 OPBT14
#endif

// (0xFF3213DC): * reserved *
    0xFFFFFFFF,

// OPT16 (0xFF3213E0): SVR control
#ifdef uses_bits
    0   << 31 |   // SVRENABLE:   SVR on/off: 0=Disabled (default), 1=Enabled       (!!!INVERT IN OPT20!!!)
    6   << 28 |   // * reserved *
    15  << 24 |   // SVRAJPRDSR:    SVR adjusting slew rate (drive ability)         (!!!INVERT IN OPT20!!!)
    1   << 23 |   // * reserved *
    7   << 20 |   // SVRAJDTN:    SVR adjusting dead time of Lo-side: OFF->Hi-side: ON  (!!!INVERT IN OPT20!!!)
    1   << 19 |   // * reserved *
    7   << 16 |   // SVRAJDTP:    SVR adjusting dead time of Hi-side: OFF->Lo-side: ON  (!!!INVERT IN OPT20!!!)
  0xFF  << 8  |   // * reserved *
  0xFF  << 0,     // SVRADNSMP:   SVR ADC sampling time                 (!!!INVERT IN OPT20!!!)
#else
    U2A_OPTB16,     // H'FF3213E0 OPBT16
#endif

// OPT17 (0xFF3213E4): SVR control
#ifdef uses_bits
  0xFF  << 24 |   // SVRADTHRESHE:  SVR ADC conversion completion state setting       (!!!INVERT IN OPT21!!!)
  0xFF  << 16 |   // SVRADTHRESH:   SVR ADC sampling starting state setting         (!!!INVERT IN OPT21!!!)
  0xFF  << 8  |   // SVRMAXDUTY:    SVR maximum on-duty setting               (!!!INVERT IN OPT21!!!)
    3   << 6  |   // * reserved *
    3   << 4  |   // SVRMINSKIPDUTY:  SVR skip minimum pulse setting              (!!!INVERT IN OPT21!!!)
    3   << 2  |   // * reserved *
    3   << 0,     // SVRSWMODE:   SVR switching frequency setting             (!!!INVERT IN OPT21!!!)
#else
    U2A_OPTB17,     // H'FF3213E4 OPBT17
#endif

// OPT18 (0xFF3213E8): SVR control
#ifdef uses_bits
      3   << 30 |   // * reserved *
  0x3FFF  << 16 |   // SVRKIVSCL:   SVR scaled KI value of VPID               (!!!INVERT IN OPT22!!!)
      3   << 14 |   // * reserved *
  0x3FFF  << 0,     // SVRKPVSCL:   SVR scaled KP value of VPID               (!!!INVERT IN OPT22!!!)
#else
    U2A_OPTB18,     // H'FF3213E8 OPBT18
#endif

// OPT19 (0xFF3213EC): SVR control
#ifdef uses_bits
    0x3FFFF << 14 |   //  * reserved *
    0x3FFF  << 0,     //  SVRKDVSCL:    SVR scaled KD value of VPID               (!!!INVERT IN OPT23!!!)
#else
    U2A_OPTB19,       // H'FF3213EC OPBT19
#endif

// OPT20 (0xFF3213F0): SVR control (inverted values)
#ifdef uses_bits
    1   << 31 |   //  SVRENABLEB:   Inverted value of SVRENABLE
    7   << 28 |   //  * reserved *
    0   << 24 |   //  SVRAJPRDSRB:  Inverted value of SVRAJPRDSR
    1   << 23 |   //  * reserved *
    0   << 20 |   //  SVRAJDTNB:    Inverted value of SVRAJDTN
    1   << 19 |   //  * reserved *
    0   << 16 |   //  SVRAJDTPB:    Inverted value of SVRAJDTP
  0xFF  << 8  |   //  * reserved *
    0   << 0,     //  SVRADNSMPB:   Inverted value of SVRADNSMP
#else
    U2A_OPTB20,     // H'FF3213F0 OPBT20
#endif

// OPT21 (0xFF3213F4): SVR control (inverted values)
#ifdef uses_bits
    0   << 24 |   //  SVRADTHRESHEB:  Inverted value of SVRADTHRESHE
    0   << 16 |   //  SVRADTHRESHB: Inverted value of SVRADTHRESH
    0   << 8  |   //  SVRMAXDUTYB:  Inverted value of SVRMAXDUTY
    3   << 6  |   //  * reserved *
    0   << 4  |   //  SVRMINSKIPDUTYB:Inverted value of SVMINSKIPDUTY
    3   << 2  |   //  * reserved *
    0   << 0,     //  SVRSWMODEB  : Inverted value of SVRSWMODE
#else
    U2A_OPTB21,     // H'FF3213F4 OPBT21
#endif

// OPT22 (0xFF3213F8): SVR control (inverted values)
#ifdef uses_bits
    3   << 30 |   //  * reserved *
    0   << 16 |   //  SVRKIVSCLB:   Inverted value of SVRKIVSCL
    3   << 14 |   //  * reserved *
    0   << 0,     //  SVRKPVSCLB:   Inverted value of SVRKPVSCL
#else
    U2A_OPTB22,   // H'FF3213F8 OPBT22
#endif

// OPT23 (0xFF3213FC):
#ifdef uses_bits
    0x3FFFF << 14 |   //  * reserved *
    0   << 0,     //  SVRKDVSCLB:   Inverted value of SVRKDVSCL
#else
    U2A_OPTB23,   // H'FF3213FC OPBT23
#endif


  0xFFFFFFFF,   // H'FF321400 Reserved
  0xFFFFFFFF,   // H'FF321404 Reserved
  0xFFFFFFFF,   // H'FF321408 Reserved
  0xFFFFFFFF,   // H'FF32140C Reserved
  0xFFFFFFFF,   // H'FF321410 Reserved
  0xFFFFFFFF,   // H'FF321414 Reserved
  0xFFFFFFFF,   // H'FF321418 Reserved
  0xFFFFFFFF,   // H'FF32141C Reserved
  0xFFFFFFFF,   // H'FF321420 Reserved
  0xFFFFFFFF,   // H'FF321424 Reserved
  0xFFFFFFFF,   // H'FF321428 Reserved
  0xFFFFFFFF,   // H'FF32142C Reserved
  0xFFFFFFFF,   // H'FF321430 Reserved
  0xFFFFFFFF,   // H'FF321434 Reserved
  0xFFFFFFFF,   // H'FF321438 Reserved
  0xFFFFFFFF,   // H'FF32143C Reserved
  0xFFFFFFFF,   // H'FF321440 Reserved
  0xFFFFFFFF,   // H'FF321444 Reserved
  0xFFFFFFFF,   // H'FF321448 Reserved
  0xFFFFFFFF,   // H'FF32144C Reserved
  0xFFFFFFFF,   // H'FF321450 Reserved
  0xFFFFFFFF,   // H'FF321454 Reserved
  0xFFFFFFFF,   // H'FF321458 Reserved
  0xFFFFFFFF,   // H'FF32145C Reserved
  0xFFFFFFFF,   // H'FF321460 Reserved
  0xFFFFFFFF,   // H'FF321464 Reserved
  0xFFFFFFFF,   // H'FF321468 Reserved
  0xFFFFFFFF,   // H'FF32146C Reserved
  0xFFFFFFFF,   // H'FF321470 Reserved
  0xFFFFFFFF,   // H'FF321474 Reserved
  0xFFFFFFFF,   // H'FF321478 Reserved
  0xFFFFFFFF,   // H'FF32147C Reserved
};


/*******************************************************************************************

/////////////////////////////////////////////////////////////////////////////////
// Block Protection Area for FPSYS0
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".BPA0x1"

const unsigned long bpa0_x1[136] =
{
  // cannot-write 300-3DF
  0xFFFFFFFF,   // H'FF3213E0 OTP Setting of Extended Data Area
  0xFFFFFFFF,   // H'FF3213E4
  0xFFFFFFFF,   // H'FF3213E8
  0xFFFFFFFF,   // H'FF3213EC
  0xFFFFFFFF,   // H'FF3213F0
  0xFFFFFFFF,   // H'FF3213F4
  0xFFFFFFFF,   // H'FF3213F8
  0xFFFFFFFF,   // H'FF3213FC

  0xFFFFFFFF,   // H'FF321400 Customer ID Protection & Erase Counter Setting for user area0 & user boot area0
  0xFFFFFFFF,   // H'FF321404
  0xFFFFFFFF,   // H'FF321408
  0xFFFFFFFF,   // H'FF32140C
  0xFFFFFFFF,   // H'FF321410
  0xFFFFFFFF,   // H'FF321414
  0xFFFFFFFF,   // H'FF321418
  0xFFFFFFFF,   // H'FF32141C
  0xFFFFFFFF,   // H'FF321420
  0xFFFFFFFF,   // H'FF321424
  0xFFFFFFFF,   // H'FF321428
  0xFFFFFFFF,   // H'FF32142C
  0xFFFFFFFF,   // H'FF321430
  0xFFFFFFFF,   // H'FF321434
  0xFFFFFFFF,   // H'FF321438
  0xFFFFFFFF,   // H'FF32143C
  0xFFFFFFFF,   // H'FF321440 Customer ID Protection & Erase Counter Setting for user area1 & user boot area1
  0xFFFFFFFF,   // H'FF321444
  0xFFFFFFFF,   // H'FF321448
  0xFFFFFFFF,   // H'FF32144C
  0xFFFFFFFF,   // H'FF321450
  0xFFFFFFFF,   // H'FF321454
  0xFFFFFFFF,   // H'FF321458
  0xFFFFFFFF,   // H'FF32145C
  0xFFFFFFFF,   // H'FF321460
  0xFFFFFFFF,   // H'FF321464
  0xFFFFFFFF,   // H'FF321468
  0xFFFFFFFF,   // H'FF32146C
  0xFFFFFFFF,   // H'FF321470
  0xFFFFFFFF,   // H'FF321474
  0xFFFFFFFF,   // H'FF321478
  0xFFFFFFFF,   // H'FF32147C

  0xFFFFFFFF,   // H'FF321480 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF321484 Reserved
  0xFFFFFFFF,   // H'FF321488 Reserved
  0xFFFFFFFF,   // H'FF32148C Reserved
  0xFFFFFFFF,   // H'FF321490 Reserved
  0xFFFFFFFF,   // H'FF321494 Reserved
  0xFFFFFFFF,   // H'FF321498 Reserved
  0xFFFFFFFF,   // H'FF32149C Reserved
  0xFFFFFFFF,   // H'FF3214A0 Reserved
  0xFFFFFFFF,   // H'FF3214A4 Reserved
  0xFFFFFFFF,   // H'FF3214A8 Reserved
  0xFFFFFFFF,   // H'FF3214AC Reserved
  0xFFFFFFFF,   // H'FF3214B0 Reserved
  0xFFFFFFFF,   // H'FF3214B4 Reserved
  0xFFFFFFFF,   // H'FF3214B8 Reserved
  0xFFFFFFFF,   // H'FF3214BC Reserved
  0xFFFFFFFF,   // H'FF3214C0 Reserved
  0xFFFFFFFF,   // H'FF3214C4 Reserved
  0xFFFFFFFF,   // H'FF3214C8 Reserved
  0xFFFFFFFF,   // H'FF3214CC Reserved
  0xFFFFFFFF,   // H'FF3214D0 Reserved
  0xFFFFFFFF,   // H'FF3214D4 Reserved
  0xFFFFFFFF,   // H'FF3214D8 Reserved
  0xFFFFFFFF,   // H'FF3214DC Reserved
  0xFFFFFFFF,   // H'FF3214E0 Reserved
  0xFFFFFFFF,   // H'FF3214E4 Reserved
  0xFFFFFFFF,   // H'FF3214E8 Reserved
  0xFFFFFFFF,   // H'FF3214EC Reserved
  0xFFFFFFFF,   // H'FF3214F0 Reserved
  0xFFFFFFFF,   // H'FF3214F4 Reserved
  0xFFFFFFFF,   // H'FF3214F8 Reserved
  0xFFFFFFFF,   // H'FF3214FC Reserved

  0xFFFFFFFF,   // H'FF321500 Reserved
  0xFFFFFFFF,   // H'FF321504 Reserved
  0xFFFFFFFF,   // H'FF321508 Reserved
  0xFFFFFFFF,   // H'FF32150C Reserved
  0xFFFFFFFF,   // H'FF321510 Reserved
  0xFFFFFFFF,   // H'FF321514 Reserved
  0xFFFFFFFF,   // H'FF321518 Reserved
  0xFFFFFFFF,   // H'FF32151C Reserved
  0xFFFFFFFF,   // H'FF321520 Reserved
  0xFFFFFFFF,   // H'FF321524 Reserved
  0xFFFFFFFF,   // H'FF321528 Reserved
  0xFFFFFFFF,   // H'FF32152C Reserved
  0xFFFFFFFF,   // H'FF321530 Reserved
  0xFFFFFFFF,   // H'FF321534 Reserved
  0xFFFFFFFF,   // H'FF321538 Reserved
  0xFFFFFFFF,   // H'FF32153C Reserved
  0xFFFFFFFF,   // H'FF321540 Reserved
  0xFFFFFFFF,   // H'FF321544 Reserved
  0xFFFFFFFF,   // H'FF321548 Reserved
  0xFFFFFFFF,   // H'FF32154C Reserved
  0xFFFFFFFF,   // H'FF321550 Reserved
  0xFFFFFFFF,   // H'FF321554 Reserved
  0xFFFFFFFF,   // H'FF321558 Reserved
  0xFFFFFFFF,   // H'FF32155C Reserved
  0xFFFFFFFF,   // H'FF321560 Reserved
  0xFFFFFFFF,   // H'FF321564 Reserved
  0xFFFFFFFF,   // H'FF321568 Reserved
  0xFFFFFFFF,   // H'FF32156C Reserved
  0xFFFFFFFF,   // H'FF321570 Reserved
  0xFFFFFFFF,   // H'FF321574 Reserved
  0xFFFFFFFF,   // H'FF321578 Reserved
  0xFFFFFFFF,   // H'FF32157C Reserved

  0xFFFFFFFF,   // H'FF321580 Reserved
  0xFFFFFFFF,   // H'FF321584 Reserved
  0xFFFFFFFF,   // H'FF321588 Reserved
  0xFFFFFFFF,   // H'FF32158C Reserved
  0xFFFFFFFF,   // H'FF321590 Reserved
  0xFFFFFFFF,   // H'FF321594 Reserved
  0xFFFFFFFF,   // H'FF321598 Reserved
  0xFFFFFFFF,   // H'FF32159C Reserved
  0xFFFFFFFF,   // H'FF3215A0 Reserved
  0xFFFFFFFF,   // H'FF3215A4 Reserved
  0xFFFFFFFF,   // H'FF3215A8 Reserved
  0xFFFFFFFF,   // H'FF3215AC Reserved
  0xFFFFFFFF,   // H'FF3215B0 Reserved
  0xFFFFFFFF,   // H'FF3215B4 Reserved
  0xFFFFFFFF,   // H'FF3215B8 Reserved
  0xFFFFFFFF,   // H'FF3215BC Reserved
  0xFFFFFFFF,   // H'FF3215C0 Reserved
  0xFFFFFFFF,   // H'FF3215C4 Reserved
  0xFFFFFFFF,   // H'FF3215C8 Reserved
  0xFFFFFFFF,   // H'FF3215CC Reserved
  0xFFFFFFFF,   // H'FF3215D0 Reserved
  0xFFFFFFFF,   // H'FF3215D4 Reserved
  0xFFFFFFFF,   // H'FF3215D8 Reserved
  0xFFFFFFFF,   // H'FF3215DC Reserved
  0xFFFFFFFF,   // H'FF3215E0 Reserved
  0xFFFFFFFF,   // H'FF3215E4 Reserved
  0xFFFFFFFF,   // H'FF3215E8 Reserved
  0xFFFFFFFF,   // H'FF3215EC Reserved
  0xFFFFFFFF,   // H'FF3215F0 Reserved
  0xFFFFFFFF,   // H'FF3215F4 Reserved
  0xFFFFFFFF,   // H'FF3215F8 Reserved
  0xFFFFFFFF,   // H'FF3215FC Reserved
  // cannot-write 600-6DF
};

#pragma ghs section rodata=".BPA0x2"

const unsigned long bpa0_x2[8] =
{
  0xFFFFFFFF,   // H'FF3216E0 Customer ID Protection Setting for Extended data area
  0xFFFFFFFF,   // H'FF3216E4
  0xFFFFFFFF,   // H'FF3216E8
  0xFFFFFFFF,   // H'FF3216EC
  0xFFFFFFFF,   // H'FF3216F0
  0xFFFFFFFF,   // H'FF3216F4
  0xFFFFFFFF,   // H'FF3216F8
  0xFFFFFFFF,   // H'FF3216FC
};

/////////////////////////////////////////////////////////////////////////////////
// Block Protection Area for FPSYS1
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".BPA1x1"

const unsigned long bpa1_x1[128] =
{
  // cannot-write 300-3FF
  0xFFFFFFFF,   // H'FF340C00 Customer ID Protection & Erase Counter Setting for user area2
  0xFFFFFFFF,   // H'FF340C04
  0xFFFFFFFF,   // H'FF340C08
  0xFFFFFFFF,   // H'FF340C0C
  0xFFFFFFFF,   // H'FF340C10
  0xFFFFFFFF,   // H'FF340C14
  0xFFFFFFFF,   // H'FF340C18
  0xFFFFFFFF,   // H'FF340C1C
  0xFFFFFFFF,   // H'FF340C20
  0xFFFFFFFF,   // H'FF340C24
  0xFFFFFFFF,   // H'FF340C28
  0xFFFFFFFF,   // H'FF340C2C
  0xFFFFFFFF,   // H'FF340C30
  0xFFFFFFFF,   // H'FF340C34
  0xFFFFFFFF,   // H'FF340C38
  0xFFFFFFFF,   // H'FF340C3C
  0xFFFFFFFF,   // H'FF340C40 Customer ID Protection & Erase Counter Setting for user area3
  0xFFFFFFFF,   // H'FF340C44
  0xFFFFFFFF,   // H'FF340C48
  0xFFFFFFFF,   // H'FF340C4C
  0xFFFFFFFF,   // H'FF340C50
  0xFFFFFFFF,   // H'FF340C54
  0xFFFFFFFF,   // H'FF340C58
  0xFFFFFFFF,   // H'FF340C5C
  0xFFFFFFFF,   // H'FF340C60
  0xFFFFFFFF,   // H'FF340C64
  0xFFFFFFFF,   // H'FF340C68
  0xFFFFFFFF,   // H'FF340C6C
  0xFFFFFFFF,   // H'FF340C70
  0xFFFFFFFF,   // H'FF340C74
  0xFFFFFFFF,   // H'FF340C78
  0xFFFFFFFF,   // H'FF340C7C

  0xFFFFFFFF,   // H'FF340C80 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF340C84 Reserved
  0xFFFFFFFF,   // H'FF340C88 Reserved
  0xFFFFFFFF,   // H'FF340C8C Reserved
  0xFFFFFFFF,   // H'FF340C90 Reserved
  0xFFFFFFFF,   // H'FF340C94 Reserved
  0xFFFFFFFF,   // H'FF340C98 Reserved
  0xFFFFFFFF,   // H'FF340C9C Reserved
  0xFFFFFFFF,   // H'FF340CA0 Reserved
  0xFFFFFFFF,   // H'FF340CA4 Reserved
  0xFFFFFFFF,   // H'FF340CA8 Reserved
  0xFFFFFFFF,   // H'FF340CAC Reserved
  0xFFFFFFFF,   // H'FF340CB0 Reserved
  0xFFFFFFFF,   // H'FF340CB4 Reserved
  0xFFFFFFFF,   // H'FF340CB8 Reserved
  0xFFFFFFFF,   // H'FF340CBC Reserved
  0xFFFFFFFF,   // H'FF340CC0 Reserved
  0xFFFFFFFF,   // H'FF340CC4 Reserved
  0xFFFFFFFF,   // H'FF340CC8 Reserved
  0xFFFFFFFF,   // H'FF340CCC Reserved
  0xFFFFFFFF,   // H'FF340CD0 Reserved
  0xFFFFFFFF,   // H'FF340CD4 Reserved
  0xFFFFFFFF,   // H'FF340CD8 Reserved
  0xFFFFFFFF,   // H'FF340CDC Reserved
  0xFFFFFFFF,   // H'FF340CE0 Reserved
  0xFFFFFFFF,   // H'FF340CE4 Reserved
  0xFFFFFFFF,   // H'FF340CE8 Reserved
  0xFFFFFFFF,   // H'FF340CEC Reserved
  0xFFFFFFFF,   // H'FF340CF0 Reserved
  0xFFFFFFFF,   // H'FF340CF4 Reserved
  0xFFFFFFFF,   // H'FF340CF8 Reserved
  0xFFFFFFFF,   // H'FF340CFC Reserved

  0xFFFFFFFF,   // H'FF340D00 Reserved
  0xFFFFFFFF,   // H'FF340D04 Reserved
  0xFFFFFFFF,   // H'FF340D08 Reserved
  0xFFFFFFFF,   // H'FF340D0C Reserved
  0xFFFFFFFF,   // H'FF340D10 Reserved
  0xFFFFFFFF,   // H'FF340D14 Reserved
  0xFFFFFFFF,   // H'FF340D18 Reserved
  0xFFFFFFFF,   // H'FF340D1C Reserved
  0xFFFFFFFF,   // H'FF340D20 Reserved
  0xFFFFFFFF,   // H'FF340D24 Reserved
  0xFFFFFFFF,   // H'FF340D28 Reserved
  0xFFFFFFFF,   // H'FF340D2C Reserved
  0xFFFFFFFF,   // H'FF340D30 Reserved
  0xFFFFFFFF,   // H'FF340D34 Reserved
  0xFFFFFFFF,   // H'FF340D38 Reserved
  0xFFFFFFFF,   // H'FF340D3C Reserved
  0xFFFFFFFF,   // H'FF340D40 Reserved
  0xFFFFFFFF,   // H'FF340D44 Reserved
  0xFFFFFFFF,   // H'FF340D48 Reserved
  0xFFFFFFFF,   // H'FF340D4C Reserved
  0xFFFFFFFF,   // H'FF340D50 Reserved
  0xFFFFFFFF,   // H'FF340D54 Reserved
  0xFFFFFFFF,   // H'FF340D58 Reserved
  0xFFFFFFFF,   // H'FF340D5C Reserved
  0xFFFFFFFF,   // H'FF340D60 Reserved
  0xFFFFFFFF,   // H'FF340D64 Reserved
  0xFFFFFFFF,   // H'FF340D68 Reserved
  0xFFFFFFFF,   // H'FF340D6C Reserved
  0xFFFFFFFF,   // H'FF340D70 Reserved
  0xFFFFFFFF,   // H'FF340D74 Reserved
  0xFFFFFFFF,   // H'FF340D78 Reserved
  0xFFFFFFFF,   // H'FF340D7C Reserved

  0xFFFFFFFF,   // H'FF340D80 Reserved
  0xFFFFFFFF,   // H'FF340D84 Reserved
  0xFFFFFFFF,   // H'FF340D88 Reserved
  0xFFFFFFFF,   // H'FF340D8C Reserved
  0xFFFFFFFF,   // H'FF340D90 Reserved
  0xFFFFFFFF,   // H'FF340D94 Reserved
  0xFFFFFFFF,   // H'FF340D98 Reserved
  0xFFFFFFFF,   // H'FF340D9C Reserved
  0xFFFFFFFF,   // H'FF340DA0 Reserved
  0xFFFFFFFF,   // H'FF340DA4 Reserved
  0xFFFFFFFF,   // H'FF340DA8 Reserved
  0xFFFFFFFF,   // H'FF340DAC Reserved
  0xFFFFFFFF,   // H'FF340DB0 Reserved
  0xFFFFFFFF,   // H'FF340DB4 Reserved
  0xFFFFFFFF,   // H'FF340DB8 Reserved
  0xFFFFFFFF,   // H'FF340DBC Reserved
  0xFFFFFFFF,   // H'FF340DC0 Reserved
  0xFFFFFFFF,   // H'FF340DC4 Reserved
  0xFFFFFFFF,   // H'FF340DC8 Reserved
  0xFFFFFFFF,   // H'FF340DCC Reserved
  0xFFFFFFFF,   // H'FF340DD0 Reserved
  0xFFFFFFFF,   // H'FF340DD4 Reserved
  0xFFFFFFFF,   // H'FF340DD8 Reserved
  0xFFFFFFFF,   // H'FF340DDC Reserved
  0xFFFFFFFF,   // H'FF340DE0 Reserved
  0xFFFFFFFF,   // H'FF340DE4 Reserved
  0xFFFFFFFF,   // H'FF340DE8 Reserved
  0xFFFFFFFF,   // H'FF340DEC Reserved
  0xFFFFFFFF,   // H'FF340DF0 Reserved
  0xFFFFFFFF,   // H'FF340DF4 Reserved
  0xFFFFFFFF,   // H'FF340DF8 Reserved
  0xFFFFFFFF,   // H'FF340DFC Reserved
  // cannot-write offset 600-7FF
};

*******************************************************************************************/

#pragma ghs section rodata=default
