/**************************************************************/
/*
*/
/**************************************************************/
MEMORY
{
    ROM        : ORIGIN  =  0x00000000,  LENGTH  =  16M
    LRAM       : ORIGIN  =  0xFDE00000,  LENGTH  =  32K
    CRAM       : ORIGIN  =  0xFE000000,  LENGTH  =  704K
    /* The following addresses cover the Back area of the HW property area */
    OTPSET     : ORIGIN  =  0xFF321200,  LENGTH  =  32
    USERBYTE   : ORIGIN  =  0xFF321300,  LENGTH  =  128
    OPTBYTE    : ORIGIN  =  0xFF321380,  LENGTH  =  256

    OTPSSA     : ORIGIN  =  0xFF322200,  LENGTH  =  64
    OTPSSAR    : ORIGIN  =  0xFF3222E0,  LENGTH  =  32
    OPTBYTESSA : ORIGIN  =  0xFF322300,  LENGTH  =  352
    OPTBYTESSAR: ORIGIN  =  0xFF322700,  LENGTH  =  32

    OTPBPA0    : ORIGIN  =  0xFF323200,  LENGTH  =  256
    BPA0x1     : ORIGIN  =  0xFF3233E0,  LENGTH  =  544
    BPA0x2     : ORIGIN  =  0xFF3236E0,  LENGTH  =  32

    OTPBPA1    : ORIGIN  =  0xFF340A00,  LENGTH  =  256
    BPA1       : ORIGIN  =  0xFF340C00,  LENGTH  =  512
}


/**************************************************************/
SECTIONS
{
/* Start of internal ROM area (iROM) */
    .reset                     align(4)         :> ROM
    .rosdata                   align(4)         :> .
    .rodata                    align(4)         :> .
    .text                      0x00010040       :> .
    .rodata0                   align(4)         :> .
    .secinfo                                    :> .

/* Local RAM */
    .sda_start                 align(4)         :> LRAM
    .sdabase                   align(4)         :> .
    .sdata                     align(4)         :> .
    .sbss                      align(4)         :> .
    .sda_end                   align(4)         :> .
    .stack                     align(4)         :> .
    .data                      align(4)         :> .
    .bss                       align(4)         :> .
    .heap	               align(4)         :> .

/* Cluster RAM */
    .tdata                     align(4)         :> CRAM
    .zdata                     align(4)         :> .
    .zbss                      align(4)         :> .

/******************************************************/
/* User Software Configuration Option Byte */
    .USER_OPBT             align(4)             :> USERBYTE

/* Option BYTE */
    .OPBT                  align(4)             :> OPTBYTE

/* OTP Setting of Configuration setting Area ***********/
/** KEEP THESE at 0xFFFFFFFF! **/
    .OTP_CSA               align(4)             :> OTPSET

/******************************************************/
/* Security Option BYTE */
    .S_OPBT                align(4)             :> OPTBYTESSA
    .S_OPBTR               align(4)             :> OPTBYTESSAR

/* OTP Setting of Security setting Area ***************/
/** KEEP THESE at 0xFFFFFFFF! **/
    .OTP_SSA               align(4)             :> OTPSSA
    .OTP_SSAR              align(4)             :> OTPSSAR

/******************************************************/
/* Setting of Block protection Area for FPSYS0 ***************/
/** KEEP THESE at 0xFFFFFFFF! **/
    .BPA0x1                align(4)             :> BPA0x1
    .BPA0x2                align(4)             :> BPA0x2
    .OTP_BPA0              align(4)             :> OTPBPA0

/******************************************************/
/* Setting of Block protection Area for FPSYS1 ***************/
/** KEEP THESE at 0xFFFFFFFF! **/
    .BPA1x1                align(4)             :> BPA1
    .OTP_BPA1              align(4)             :> OTPBPA1

}

/*===========================================================================*/
/*      End of File                                                          */
/*===========================================================================*/



