/*******************************************************************************
*
* KEEP THESE at 0xFFFFFFFF!
*
*******************************************************************************/

/******************************************************************************
* File Name : otp_settings.c
* Version : 1.21
* Device(s) : RH850/U2x
* Description : OTP Setting of Configuration Setting Area.
*               OTP Setting of Security Setting Area.
*               OTP Setting of Block Protection Area 0/1.
*******************************************************************************
* History : DD.MM.YYYY Version Description
*         : 08.11.2021 1.21 iSYSTEM/TASKING extensions for OTPs
******************************************************************************/

#pragma ghs section rodata=".OTP_CSA"

const unsigned long otp_CSA[8] = 
{
  0xFFFFFFFF,   // H'FF321200
  0xFFFFFFFF,   // H'FF321204
  0xFFFFFFFF,   // H'FF321208

  0xFFFFFFFF,   // H'FF32120C Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF321210 Reserved
  0xFFFFFFFF,   // H'FF321214 Reserved
  0xFFFFFFFF,   // H'FF321218 Reserved
  0xFFFFFFFF    // H'FF32121C Reserved
};

/**************************************

#pragma ghs section rodata=".OTP_SSA"

const unsigned long otp_SSA[16] = 
{
  0xFFFFFFFF,   // H'FF322200
  0xFFFFFFFF,   // H'FF322204
  0xFFFFFFFF,   // H'FF322208

  0xFFFFFFFF,   // H'FF32220C Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF322210 Reserved
  0xFFFFFFFF,   // H'FF322214 Reserved
  0xFFFFFFFF,   // H'FF322218 Reserved
  0xFFFFFFFF,   // H'FF32221C Reserved

  0xFFFFFFFF,   // H'FF322220

  0xFFFFFFFF,   // H'FF322224 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF322228 Reserved
  0xFFFFFFFF,   // H'FF32222C Reserved
  0xFFFFFFFF,   // H'FF322230 Reserved
  0xFFFFFFFF,   // H'FF322234 Reserved
  0xFFFFFFFF,   // H'FF322238 Reserved
  0xFFFFFFFF    // H'FF32223C Reserved
};

#pragma ghs section rodata=".OTP_SSAR"
// these are separated from otp_SSA above with a reserved, erased section FF322240-FF3222DF
const unsigned long otp_SSAR[8] = {
  0xFFFFFFFF,   // H'FF3222E0 Reserved
  0xFFFFFFFF,   // H'FF3222E4 Reserved
  0xFFFFFFFF,   // H'FF3222E8 Reserved
  0xFFFFFFFF,   // H'FF3222EC Reserved
  0xFFFFFFFF,   // H'FF3222F0 Reserved
  0xFFFFFFFF,   // H'FF3222F4 Reserved
  0xFFFFFFFF,   // H'FF3222F8 Reserved
  0xFFFFFFFF,   // H'FF3222FC Reserved
};

*******************************************************************************************/

/*******************************************************************************************

#pragma ghs section rodata=".OTP_BPA0"

const unsigned long otp_BPA0[64] = 
{
  0xFFFFFFFF,   // H'FF321200 OTP Setting of User area 0
  0xFFFFFFFF,   // H'FF321204
  0xFFFFFFFF,   // H'FF321208
  0xFFFFFFFF,   // H'FF32120C
  0xFFFFFFFF,   // H'FF321210
  0xFFFFFFFF,   // H'FF321214
  0xFFFFFFFF,   // H'FF321218
  0xFFFFFFFF,   // H'FF32121C
  0xFFFFFFFF,   // H'FF321220 OTP Setting of User area 1
  0xFFFFFFFF,   // H'FF321224
  0xFFFFFFFF,   // H'FF321228
  0xFFFFFFFF,   // H'FF32122C
  0xFFFFFFFF,   // H'FF321230
  0xFFFFFFFF,   // H'FF321234
  0xFFFFFFFF,   // H'FF321238
  0xFFFFFFFF,   // H'FF32123C
  0xFFFFFFFF,   // H'FF321240 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF321244 Reserved
  0xFFFFFFFF,   // H'FF321248 Reserved
  0xFFFFFFFF,   // H'FF32124C Reserved
  0xFFFFFFFF,   // H'FF321250 Reserved
  0xFFFFFFFF,   // H'FF321254 Reserved
  0xFFFFFFFF,   // H'FF321258 Reserved
  0xFFFFFFFF,   // H'FF32125C Reserved
  0xFFFFFFFF,   // H'FF321260 Reserved
  0xFFFFFFFF,   // H'FF321264 Reserved
  0xFFFFFFFF,   // H'FF321268 Reserved
  0xFFFFFFFF,   // H'FF32126C Reserved
  0xFFFFFFFF,   // H'FF321270 Reserved
  0xFFFFFFFF,   // H'FF321274 Reserved
  0xFFFFFFFF,   // H'FF321278 Reserved
  0xFFFFFFFF,   // H'FF32127C Reserved

  0xFFFFFFFF,   // H'FF321280 Reserved
  0xFFFFFFFF,   // H'FF321284 Reserved
  0xFFFFFFFF,   // H'FF321288 Reserved
  0xFFFFFFFF,   // H'FF32128C Reserved
  0xFFFFFFFF,   // H'FF321290 Reserved
  0xFFFFFFFF,   // H'FF321294 Reserved
  0xFFFFFFFF,   // H'FF321298 Reserved
  0xFFFFFFFF,   // H'FF32129C Reserved
  0xFFFFFFFF,   // H'FF3212A0 Reserved
  0xFFFFFFFF,   // H'FF3212A4 Reserved
  0xFFFFFFFF,   // H'FF3212A8 Reserved
  0xFFFFFFFF,   // H'FF3212AC Reserved
  0xFFFFFFFF,   // H'FF3212B0 Reserved
  0xFFFFFFFF,   // H'FF3212B4 Reserved
  0xFFFFFFFF,   // H'FF3212B8 Reserved
  0xFFFFFFFF,   // H'FF3212BC Reserved
  0xFFFFFFFF,   // H'FF3212C0 Reserved
  0xFFFFFFFF,   // H'FF3212C4 Reserved
  0xFFFFFFFF,   // H'FF3212C8 Reserved
  0xFFFFFFFF,   // H'FF3212CC Reserved
  0xFFFFFFFF,   // H'FF3212D0 Reserved
  0xFFFFFFFF,   // H'FF3212D4 Reserved
  0xFFFFFFFF,   // H'FF3212D8 Reserved
  0xFFFFFFFF,   // H'FF3212DC Reserved
  0xFFFFFFFF,   // H'FF3212E0 Reserved
  0xFFFFFFFF,   // H'FF3212E4 Reserved
  0xFFFFFFFF,   // H'FF3212E8 Reserved
  0xFFFFFFFF,   // H'FF3212EC Reserved
  0xFFFFFFFF,   // H'FF3212F0 Reserved
  0xFFFFFFFF,   // H'FF3212F4 Reserved
  0xFFFFFFFF,   // H'FF3212F8 Reserved
  0xFFFFFFFF,   // H'FF3212FC Reserved
};

#pragma ghs section rodata=".OTP_BPA1"

const unsigned long otp_BPA1[64] = 
{
  0xFFFFFFFF,   // H'FF3400A00 OTP Setting of User area 2
  0xFFFFFFFF,   // H'FF3400A04
  0xFFFFFFFF,   // H'FF3400A08
  0xFFFFFFFF,   // H'FF3400A0C
  0xFFFFFFFF,   // H'FF3400A10
  0xFFFFFFFF,   // H'FF3400A14
  0xFFFFFFFF,   // H'FF3400A18
  0xFFFFFFFF,   // H'FF3400A1C
  0xFFFFFFFF,   // H'FF3400A20 OTP Setting of User area 3
  0xFFFFFFFF,   // H'FF3400A24
  0xFFFFFFFF,   // H'FF3400A28
  0xFFFFFFFF,   // H'FF3400A2C
  0xFFFFFFFF,   // H'FF3400A30
  0xFFFFFFFF,   // H'FF3400A34
  0xFFFFFFFF,   // H'FF3400A38
  0xFFFFFFFF,   // H'FF3400A3C
  0xFFFFFFFF,   // H'FF3400A40 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF3400A44 Reserved
  0xFFFFFFFF,   // H'FF3400A48 Reserved
  0xFFFFFFFF,   // H'FF3400A4C Reserved
  0xFFFFFFFF,   // H'FF3400A50 Reserved
  0xFFFFFFFF,   // H'FF3400A54 Reserved
  0xFFFFFFFF,   // H'FF3400A58 Reserved
  0xFFFFFFFF,   // H'FF3400A5C Reserved
  0xFFFFFFFF,   // H'FF3400A60 Reserved
  0xFFFFFFFF,   // H'FF3400A64 Reserved
  0xFFFFFFFF,   // H'FF3400A68 Reserved
  0xFFFFFFFF,   // H'FF3400A6C Reserved
  0xFFFFFFFF,   // H'FF3400A70 Reserved
  0xFFFFFFFF,   // H'FF3400A74 Reserved
  0xFFFFFFFF,   // H'FF3400A78 Reserved
  0xFFFFFFFF,   // H'FF3400A7C Reserved

  0xFFFFFFFF,   // H'FF340A80 Reserved
  0xFFFFFFFF,   // H'FF340A84 Reserved
  0xFFFFFFFF,   // H'FF340A88 Reserved
  0xFFFFFFFF,   // H'FF340A8C Reserved
  0xFFFFFFFF,   // H'FF340A90 Reserved
  0xFFFFFFFF,   // H'FF340A94 Reserved
  0xFFFFFFFF,   // H'FF340A98 Reserved
  0xFFFFFFFF,   // H'FF340A9C Reserved
  0xFFFFFFFF,   // H'FF340AA0 Reserved
  0xFFFFFFFF,   // H'FF340AA4 Reserved
  0xFFFFFFFF,   // H'FF340AA8 Reserved
  0xFFFFFFFF,   // H'FF340AAC Reserved
  0xFFFFFFFF,   // H'FF340AB0 Reserved
  0xFFFFFFFF,   // H'FF340AB4 Reserved
  0xFFFFFFFF,   // H'FF340AB8 Reserved
  0xFFFFFFFF,   // H'FF340ABC Reserved
  0xFFFFFFFF,   // H'FF340AC0 Reserved
  0xFFFFFFFF,   // H'FF340AC4 Reserved
  0xFFFFFFFF,   // H'FF340AC8 Reserved
  0xFFFFFFFF,   // H'FF340ACC Reserved
  0xFFFFFFFF,   // H'FF340AD0 Reserved
  0xFFFFFFFF,   // H'FF340AD4 Reserved
  0xFFFFFFFF,   // H'FF340AD8 Reserved
  0xFFFFFFFF,   // H'FF340ADC Reserved
  0xFFFFFFFF,   // H'FF340AE0 Reserved
  0xFFFFFFFF,   // H'FF340AE4 Reserved
  0xFFFFFFFF,   // H'FF340AE8 Reserved
  0xFFFFFFFF,   // H'FF340AEC Reserved
  0xFFFFFFFF,   // H'FF340AF0 Reserved
  0xFFFFFFFF,   // H'FF340AF4 Reserved
  0xFFFFFFFF,   // H'FF340AF8 Reserved
  0xFFFFFFFF,   // H'FF340AFC Reserved
};

*******************************************/

#pragma ghs section rodata=default
