/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
* Copyright (C) 2017 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/

/******************************************************************************
* File Name : opbt.c
* Version : 1.21
* Device(s) : RH850/U2x
* Description : This is the main tutorial code.
*******************************************************************************
* History : DD.MM.YYYY Version Description
*         : 15.10.2018 1.00 First Release
*         : 12.11.2019 1.10 Added structures for bit settings
*         : 08.11.2021 1.21 iSYSTEM/TASKING extensions for BPA0/1
*         : 08.08.2023 1.23 U2B version
******************************************************************************/

//******************************************************
// should match the device that you have connected
//******************************************************
#define U2B_OPTB00  0x3FE30010        // Default setting
#define U2B_OPTB01  0x007B0000        // Default setting
#define U2B_OPTB02  0x7FFFFFFF        // Default setting
#define U2B_OPTB03  0xF1FF7EFC        // Default/device-specific, operating mode set to "Normal"
#define U2B_OPTB04  0x0C0C0C0B        // Default setting
#define U2B_OPTB05  0xFFFFFFFF        // Default setting
#define U2B_OPTB06  0xFFFF3FCF        // Default setting
#define U2B_OPTB07  0xFFFFFFFF        // Default setting
#define U2B_OPTB08  0xE04FFFFF        // Default setting
#define U2B_OPTB09  0xFFFC0F7F        // Default setting * device-specific
#define U2B_OPTB10  0xF9FD288E        // Default setting
#define U2B_OPTB11  0xEFFFFFFF        // Default setting
#define U2B_OPTB12  0xFFFFFFFD        // Default setting
#define U2B_OPTB13  0xFFFFFFFF        // Default setting
#define U2B_OPTB14  0xFF7F8004        // Default setting * device-specific
#define U2B_OPTB15  0xFF7F0004        // Default setting * device-specific
#define U2B_OPTB16  0x74FFFF10        // Default setting
#define U2B_OPTB17  0xF9AAFCFC        // Default setting
#define U2B_OPTB18  0xC26BC1CE        // Default setting
#define U2B_OPTB19  0xFFFFC203        // Default setting
#define U2B_OPTB20  ~U2B_OPTB16|0x4088FF00  // Inverted value of OPTB16, set reserved bits
#define U2B_OPTB21  ~U2B_OPTB17|0x000000CC  // Inverted value of OPTB17, set reserved bits
#define U2B_OPTB22  ~U2B_OPTB18|0xC000C000  // Inverted value of OPTB18, set reserved bits
#define U2B_OPTB23  ~U2B_OPTB19|0xFFFFC000  // Inverted value of OPTB19, set reserved bits
#define U2B_OPTB24  0xFFFFFFFC        // Default setting * device-specific
#define U2B_OPTB25  0xFFC0F3FF        // Default setting
#define U2B_OPTB26  0xFFFF0010        // Default setting
#define U2B_OPTB27  0xFFFF0000        // Default setting
#define U2B_OPTB28  0xFFFFFFFF        // Default setting

#define U2B_OPTB36  0xF184C8FF        // Default setting * device-specific
#define U2B_OPTB37  0x02EFFF55        // Default setting (in UM: 0x02EFFFFF)
#define U2B_OPTB38  0x00000000        // Default setting
#define U2B_OPTB39  0x00000000        // Default setting
#define U2B_OPTB40  0xFF00FCFF        // Default setting

/////////////////////////////////////////////////////////////////////////////////
// Configuration Setting Area (Option Bytes)
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".OPBT"
// 0xF1FF7EFC
const unsigned long opbt[64] =
{
  0x00000000,   // 0xFF321380 Reset Vector (PE0)
  0x00000000,   // 0xFF321384 Reset Vector (PE1)
  0x00000000,   // 0xFF321388 Reset Vector (PE2)
  0x00000000,   // 0xFF32138C Reset Vector (PE3)
  0x00000000,   // 0xFF321390 Reset Vector (PE4)
  0x00000000,   // 0xFF321394 Reset Vector (PE5)
  0x00000000,   // 0xFF321398 Reserved
  0x00000000,   // 0xFF32139C Reserved


  U2B_OPTB00, // OPBT0 (0xFF3213A0): WDTBA configuration
  U2B_OPTB01, // OPBT1 (0xFF3213A4): WDTB0-3 configuration
  U2B_OPTB02, // OPBT2 (0xFF3213A8):
  U2B_OPTB03, // OPBT3 (FF3213AC): PE1-3 configuration, BIST configuration
  U2B_OPTB04, // OPBT4 (0xFF3213B0): VMON configuration
  U2B_OPTB05, // OPBT5 (0xFF3213B4): * reserved * must be programmed
  U2B_OPTB06, // OPBT6 (0xFF3213B8): RAM initialization mode
  U2B_OPTB07, // OPBT7 (0xFF3213BC):  RAM initialization mode
  U2B_OPTB08, // OPBT8 (0xFF3213C0): Ethernet xII selection
  U2B_OPTB09, // OPBT9 (0xFF3213C4):
  U2B_OPTB10, // OPBT10 (0xFF3213C8): MainOSC configuration
  U2B_OPTB11, // OPBT11 (0xFF3213CC):
  U2B_OPTB12, // OPBT12 (0xFF3213D0): Code flash memory mapping
  U2B_OPTB13, // OPBT13 (0xFF3213D4): Double map mode switching of cluster 2/1/0
  U2B_OPTB14, // OPBT14 (0xFF3213D8): SGMII configuration
  U2B_OPTB15, // OPBT15 (0xFF3213DC): SGMII configuration

  U2B_OPTB16, // OPBT16 (0xFF3213E0): SVR control
  U2B_OPTB17, // OPBT17 (0xFF3213E4): SVR control
  U2B_OPTB18, // OPBT18 (0xFF3213E8): SVR control
  U2B_OPTB19, // OPBT19 (0xFF3213EC): SVR control
  U2B_OPTB20, // OPBT20 (0xFF3213F0): SVR control (inverted values)
  U2B_OPTB21, // OPBT21 (0xFF3213F4): SVR control (inverted values)
  U2B_OPTB22, // OPBT22 (0xFF3213F8): SVR control (inverted values)
  U2B_OPTB23, // OPBT23 (0xFF3213FC): SVR control (inverted values)

  U2B_OPTB24,   // 0xFF321400 OPBT24
  U2B_OPTB25,   // 0xFF321404 OPBT25
  U2B_OPTB26,   // 0xFF321408 OPBT26
  U2B_OPTB27,   // 0xFF32140C OPBT27
  U2B_OPTB28,   // 0xFF321410 OPBT28

  0xFFFFFFFF,   // 0xFF321414 Reserved
  0xFFFFFFFF,   // 0xFF321418 Reserved
  0xFFFFFFFF,   // 0xFF32141C Reserved
  0x60000055,   // 0xFF321420 Reserved
  0x60000056,   // 0xFF321424 Reserved
  0xF0F5EC01,   // 0xFF321428 Reserved
  0x0A180001,   // 0xFF32142C Reserved

  U2B_OPTB36,   // 0xFF321430 OPBT36
  U2B_OPTB37,   // 0xFF321434 OPBT37
  U2B_OPTB38,   // 0xFF321438 OPBT38
  U2B_OPTB39,   // 0xFF32143C OPBT39
  U2B_OPTB40,   // 0xFF321440 OPBT40

  0xFFFFFFFF,   // 0xFF321444 Reserved
  0xFFFFFFFF,   // 0xFF321448 Reserved
  0xFFFFFFFF,   // 0xFF32144C Reserved
  0xFFFFFFFF,   // 0xFF321450 Reserved
  0xFFFFFFFF,   // 0xFF321454 Reserved
  0xFFFFFFFF,   // 0xFF321458 Reserved
  0xFFFFFFFF,   // 0xFF32145C Reserved
  0xFFFFFFFF,   // 0xFF321460 Reserved
  0xFFFFFFFF,   // 0xFF321464 Reserved
  0xFFFFFFFF,   // 0xFF321468 Reserved
  0xFFFFFFFF,   // 0xFF32146C Reserved
  0xFFFFFFFF,   // 0xFF321470 Reserved
  0xFFFFFFFF,   // 0xFF321474 Reserved
  0xFFFFFFFF,   // 0xFF321478 Reserved
  0xFFFFFFFF,   // 0xFF32147C Reserved

};


/*******************************************************************************************

/////////////////////////////////////////////////////////////////////////////////
// Block Protection Area for FPSYS0
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".BPA0x1"

const unsigned long bpa0_x1[136] =
{
  // cannot-write 300-3DF
  0xFFFFFFFF,   // H'FF3213E0 OTP Setting of Extended Data Area
  0xFFFFFFFF,   // H'FF3213E4
  0xFFFFFFFF,   // H'FF3213E8
  0xFFFFFFFF,   // H'FF3213EC
  0xFFFFFFFF,   // H'FF3213F0
  0xFFFFFFFF,   // H'FF3213F4
  0xFFFFFFFF,   // H'FF3213F8
  0xFFFFFFFF,   // H'FF3213FC

  0xFFFFFFFF,   // H'FF321400 Customer ID Protection & Erase Counter Setting for user area0 & user boot area0
  0xFFFFFFFF,   // H'FF321404
  0xFFFFFFFF,   // H'FF321408
  0xFFFFFFFF,   // H'FF32140C
  0xFFFFFFFF,   // H'FF321410
  0xFFFFFFFF,   // H'FF321414
  0xFFFFFFFF,   // H'FF321418
  0xFFFFFFFF,   // H'FF32141C
  0xFFFFFFFF,   // H'FF321420
  0xFFFFFFFF,   // H'FF321424
  0xFFFFFFFF,   // H'FF321428
  0xFFFFFFFF,   // H'FF32142C
  0xFFFFFFFF,   // H'FF321430
  0xFFFFFFFF,   // H'FF321434
  0xFFFFFFFF,   // H'FF321438
  0xFFFFFFFF,   // H'FF32143C
  0xFFFFFFFF,   // H'FF321440 Customer ID Protection & Erase Counter Setting for user area1 & user boot area1
  0xFFFFFFFF,   // H'FF321444
  0xFFFFFFFF,   // H'FF321448
  0xFFFFFFFF,   // H'FF32144C
  0xFFFFFFFF,   // H'FF321450
  0xFFFFFFFF,   // H'FF321454
  0xFFFFFFFF,   // H'FF321458
  0xFFFFFFFF,   // H'FF32145C
  0xFFFFFFFF,   // H'FF321460
  0xFFFFFFFF,   // H'FF321464
  0xFFFFFFFF,   // H'FF321468
  0xFFFFFFFF,   // H'FF32146C
  0xFFFFFFFF,   // H'FF321470
  0xFFFFFFFF,   // H'FF321474
  0xFFFFFFFF,   // H'FF321478
  0xFFFFFFFF,   // H'FF32147C

  0xFFFFFFFF,   // H'FF321480 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF321484 Reserved
  0xFFFFFFFF,   // H'FF321488 Reserved
  0xFFFFFFFF,   // H'FF32148C Reserved
  0xFFFFFFFF,   // H'FF321490 Reserved
  0xFFFFFFFF,   // H'FF321494 Reserved
  0xFFFFFFFF,   // H'FF321498 Reserved
  0xFFFFFFFF,   // H'FF32149C Reserved
  0xFFFFFFFF,   // H'FF3214A0 Reserved
  0xFFFFFFFF,   // H'FF3214A4 Reserved
  0xFFFFFFFF,   // H'FF3214A8 Reserved
  0xFFFFFFFF,   // H'FF3214AC Reserved
  0xFFFFFFFF,   // H'FF3214B0 Reserved
  0xFFFFFFFF,   // H'FF3214B4 Reserved
  0xFFFFFFFF,   // H'FF3214B8 Reserved
  0xFFFFFFFF,   // H'FF3214BC Reserved
  0xFFFFFFFF,   // H'FF3214C0 Reserved
  0xFFFFFFFF,   // H'FF3214C4 Reserved
  0xFFFFFFFF,   // H'FF3214C8 Reserved
  0xFFFFFFFF,   // H'FF3214CC Reserved
  0xFFFFFFFF,   // H'FF3214D0 Reserved
  0xFFFFFFFF,   // H'FF3214D4 Reserved
  0xFFFFFFFF,   // H'FF3214D8 Reserved
  0xFFFFFFFF,   // H'FF3214DC Reserved
  0xFFFFFFFF,   // H'FF3214E0 Reserved
  0xFFFFFFFF,   // H'FF3214E4 Reserved
  0xFFFFFFFF,   // H'FF3214E8 Reserved
  0xFFFFFFFF,   // H'FF3214EC Reserved
  0xFFFFFFFF,   // H'FF3214F0 Reserved
  0xFFFFFFFF,   // H'FF3214F4 Reserved
  0xFFFFFFFF,   // H'FF3214F8 Reserved
  0xFFFFFFFF,   // H'FF3214FC Reserved

  0xFFFFFFFF,   // H'FF321500 Reserved
  0xFFFFFFFF,   // H'FF321504 Reserved
  0xFFFFFFFF,   // H'FF321508 Reserved
  0xFFFFFFFF,   // H'FF32150C Reserved
  0xFFFFFFFF,   // H'FF321510 Reserved
  0xFFFFFFFF,   // H'FF321514 Reserved
  0xFFFFFFFF,   // H'FF321518 Reserved
  0xFFFFFFFF,   // H'FF32151C Reserved
  0xFFFFFFFF,   // H'FF321520 Reserved
  0xFFFFFFFF,   // H'FF321524 Reserved
  0xFFFFFFFF,   // H'FF321528 Reserved
  0xFFFFFFFF,   // H'FF32152C Reserved
  0xFFFFFFFF,   // H'FF321530 Reserved
  0xFFFFFFFF,   // H'FF321534 Reserved
  0xFFFFFFFF,   // H'FF321538 Reserved
  0xFFFFFFFF,   // H'FF32153C Reserved
  0xFFFFFFFF,   // H'FF321540 Reserved
  0xFFFFFFFF,   // H'FF321544 Reserved
  0xFFFFFFFF,   // H'FF321548 Reserved
  0xFFFFFFFF,   // H'FF32154C Reserved
  0xFFFFFFFF,   // H'FF321550 Reserved
  0xFFFFFFFF,   // H'FF321554 Reserved
  0xFFFFFFFF,   // H'FF321558 Reserved
  0xFFFFFFFF,   // H'FF32155C Reserved
  0xFFFFFFFF,   // H'FF321560 Reserved
  0xFFFFFFFF,   // H'FF321564 Reserved
  0xFFFFFFFF,   // H'FF321568 Reserved
  0xFFFFFFFF,   // H'FF32156C Reserved
  0xFFFFFFFF,   // H'FF321570 Reserved
  0xFFFFFFFF,   // H'FF321574 Reserved
  0xFFFFFFFF,   // H'FF321578 Reserved
  0xFFFFFFFF,   // H'FF32157C Reserved

  0xFFFFFFFF,   // H'FF321580 Reserved
  0xFFFFFFFF,   // H'FF321584 Reserved
  0xFFFFFFFF,   // H'FF321588 Reserved
  0xFFFFFFFF,   // H'FF32158C Reserved
  0xFFFFFFFF,   // H'FF321590 Reserved
  0xFFFFFFFF,   // H'FF321594 Reserved
  0xFFFFFFFF,   // H'FF321598 Reserved
  0xFFFFFFFF,   // H'FF32159C Reserved
  0xFFFFFFFF,   // H'FF3215A0 Reserved
  0xFFFFFFFF,   // H'FF3215A4 Reserved
  0xFFFFFFFF,   // H'FF3215A8 Reserved
  0xFFFFFFFF,   // H'FF3215AC Reserved
  0xFFFFFFFF,   // H'FF3215B0 Reserved
  0xFFFFFFFF,   // H'FF3215B4 Reserved
  0xFFFFFFFF,   // H'FF3215B8 Reserved
  0xFFFFFFFF,   // H'FF3215BC Reserved
  0xFFFFFFFF,   // H'FF3215C0 Reserved
  0xFFFFFFFF,   // H'FF3215C4 Reserved
  0xFFFFFFFF,   // H'FF3215C8 Reserved
  0xFFFFFFFF,   // H'FF3215CC Reserved
  0xFFFFFFFF,   // H'FF3215D0 Reserved
  0xFFFFFFFF,   // H'FF3215D4 Reserved
  0xFFFFFFFF,   // H'FF3215D8 Reserved
  0xFFFFFFFF,   // H'FF3215DC Reserved
  0xFFFFFFFF,   // H'FF3215E0 Reserved
  0xFFFFFFFF,   // H'FF3215E4 Reserved
  0xFFFFFFFF,   // H'FF3215E8 Reserved
  0xFFFFFFFF,   // H'FF3215EC Reserved
  0xFFFFFFFF,   // H'FF3215F0 Reserved
  0xFFFFFFFF,   // H'FF3215F4 Reserved
  0xFFFFFFFF,   // H'FF3215F8 Reserved
  0xFFFFFFFF,   // H'FF3215FC Reserved
  // cannot-write 600-6DF
};

#pragma ghs section rodata=".BPA0x2"

const unsigned long bpa0_x2[8] =
{
  0xFFFFFFFF,   // H'FF3216E0 Customer ID Protection Setting for Extended data area
  0xFFFFFFFF,   // H'FF3216E4
  0xFFFFFFFF,   // H'FF3216E8
  0xFFFFFFFF,   // H'FF3216EC
  0xFFFFFFFF,   // H'FF3216F0
  0xFFFFFFFF,   // H'FF3216F4
  0xFFFFFFFF,   // H'FF3216F8
  0xFFFFFFFF,   // H'FF3216FC
};

/////////////////////////////////////////////////////////////////////////////////
// Block Protection Area for FPSYS1
/////////////////////////////////////////////////////////////////////////////////

#pragma ghs section rodata=".BPA1x1"

const unsigned long bpa1_x1[128] =
{
  // cannot-write 300-3FF
  0xFFFFFFFF,   // H'FF340C00 Customer ID Protection & Erase Counter Setting for user area2
  0xFFFFFFFF,   // H'FF340C04
  0xFFFFFFFF,   // H'FF340C08
  0xFFFFFFFF,   // H'FF340C0C
  0xFFFFFFFF,   // H'FF340C10
  0xFFFFFFFF,   // H'FF340C14
  0xFFFFFFFF,   // H'FF340C18
  0xFFFFFFFF,   // H'FF340C1C
  0xFFFFFFFF,   // H'FF340C20
  0xFFFFFFFF,   // H'FF340C24
  0xFFFFFFFF,   // H'FF340C28
  0xFFFFFFFF,   // H'FF340C2C
  0xFFFFFFFF,   // H'FF340C30
  0xFFFFFFFF,   // H'FF340C34
  0xFFFFFFFF,   // H'FF340C38
  0xFFFFFFFF,   // H'FF340C3C
  0xFFFFFFFF,   // H'FF340C40 Customer ID Protection & Erase Counter Setting for user area3
  0xFFFFFFFF,   // H'FF340C44
  0xFFFFFFFF,   // H'FF340C48
  0xFFFFFFFF,   // H'FF340C4C
  0xFFFFFFFF,   // H'FF340C50
  0xFFFFFFFF,   // H'FF340C54
  0xFFFFFFFF,   // H'FF340C58
  0xFFFFFFFF,   // H'FF340C5C
  0xFFFFFFFF,   // H'FF340C60
  0xFFFFFFFF,   // H'FF340C64
  0xFFFFFFFF,   // H'FF340C68
  0xFFFFFFFF,   // H'FF340C6C
  0xFFFFFFFF,   // H'FF340C70
  0xFFFFFFFF,   // H'FF340C74
  0xFFFFFFFF,   // H'FF340C78
  0xFFFFFFFF,   // H'FF340C7C

  0xFFFFFFFF,   // H'FF340C80 Reserved (need to be programmed)
  0xFFFFFFFF,   // H'FF340C84 Reserved
  0xFFFFFFFF,   // H'FF340C88 Reserved
  0xFFFFFFFF,   // H'FF340C8C Reserved
  0xFFFFFFFF,   // H'FF340C90 Reserved
  0xFFFFFFFF,   // H'FF340C94 Reserved
  0xFFFFFFFF,   // H'FF340C98 Reserved
  0xFFFFFFFF,   // H'FF340C9C Reserved
  0xFFFFFFFF,   // H'FF340CA0 Reserved
  0xFFFFFFFF,   // H'FF340CA4 Reserved
  0xFFFFFFFF,   // H'FF340CA8 Reserved
  0xFFFFFFFF,   // H'FF340CAC Reserved
  0xFFFFFFFF,   // H'FF340CB0 Reserved
  0xFFFFFFFF,   // H'FF340CB4 Reserved
  0xFFFFFFFF,   // H'FF340CB8 Reserved
  0xFFFFFFFF,   // H'FF340CBC Reserved
  0xFFFFFFFF,   // H'FF340CC0 Reserved
  0xFFFFFFFF,   // H'FF340CC4 Reserved
  0xFFFFFFFF,   // H'FF340CC8 Reserved
  0xFFFFFFFF,   // H'FF340CCC Reserved
  0xFFFFFFFF,   // H'FF340CD0 Reserved
  0xFFFFFFFF,   // H'FF340CD4 Reserved
  0xFFFFFFFF,   // H'FF340CD8 Reserved
  0xFFFFFFFF,   // H'FF340CDC Reserved
  0xFFFFFFFF,   // H'FF340CE0 Reserved
  0xFFFFFFFF,   // H'FF340CE4 Reserved
  0xFFFFFFFF,   // H'FF340CE8 Reserved
  0xFFFFFFFF,   // H'FF340CEC Reserved
  0xFFFFFFFF,   // H'FF340CF0 Reserved
  0xFFFFFFFF,   // H'FF340CF4 Reserved
  0xFFFFFFFF,   // H'FF340CF8 Reserved
  0xFFFFFFFF,   // H'FF340CFC Reserved

  0xFFFFFFFF,   // H'FF340D00 Reserved
  0xFFFFFFFF,   // H'FF340D04 Reserved
  0xFFFFFFFF,   // H'FF340D08 Reserved
  0xFFFFFFFF,   // H'FF340D0C Reserved
  0xFFFFFFFF,   // H'FF340D10 Reserved
  0xFFFFFFFF,   // H'FF340D14 Reserved
  0xFFFFFFFF,   // H'FF340D18 Reserved
  0xFFFFFFFF,   // H'FF340D1C Reserved
  0xFFFFFFFF,   // H'FF340D20 Reserved
  0xFFFFFFFF,   // H'FF340D24 Reserved
  0xFFFFFFFF,   // H'FF340D28 Reserved
  0xFFFFFFFF,   // H'FF340D2C Reserved
  0xFFFFFFFF,   // H'FF340D30 Reserved
  0xFFFFFFFF,   // H'FF340D34 Reserved
  0xFFFFFFFF,   // H'FF340D38 Reserved
  0xFFFFFFFF,   // H'FF340D3C Reserved
  0xFFFFFFFF,   // H'FF340D40 Reserved
  0xFFFFFFFF,   // H'FF340D44 Reserved
  0xFFFFFFFF,   // H'FF340D48 Reserved
  0xFFFFFFFF,   // H'FF340D4C Reserved
  0xFFFFFFFF,   // H'FF340D50 Reserved
  0xFFFFFFFF,   // H'FF340D54 Reserved
  0xFFFFFFFF,   // H'FF340D58 Reserved
  0xFFFFFFFF,   // H'FF340D5C Reserved
  0xFFFFFFFF,   // H'FF340D60 Reserved
  0xFFFFFFFF,   // H'FF340D64 Reserved
  0xFFFFFFFF,   // H'FF340D68 Reserved
  0xFFFFFFFF,   // H'FF340D6C Reserved
  0xFFFFFFFF,   // H'FF340D70 Reserved
  0xFFFFFFFF,   // H'FF340D74 Reserved
  0xFFFFFFFF,   // H'FF340D78 Reserved
  0xFFFFFFFF,   // H'FF340D7C Reserved

  0xFFFFFFFF,   // H'FF340D80 Reserved
  0xFFFFFFFF,   // H'FF340D84 Reserved
  0xFFFFFFFF,   // H'FF340D88 Reserved
  0xFFFFFFFF,   // H'FF340D8C Reserved
  0xFFFFFFFF,   // H'FF340D90 Reserved
  0xFFFFFFFF,   // H'FF340D94 Reserved
  0xFFFFFFFF,   // H'FF340D98 Reserved
  0xFFFFFFFF,   // H'FF340D9C Reserved
  0xFFFFFFFF,   // H'FF340DA0 Reserved
  0xFFFFFFFF,   // H'FF340DA4 Reserved
  0xFFFFFFFF,   // H'FF340DA8 Reserved
  0xFFFFFFFF,   // H'FF340DAC Reserved
  0xFFFFFFFF,   // H'FF340DB0 Reserved
  0xFFFFFFFF,   // H'FF340DB4 Reserved
  0xFFFFFFFF,   // H'FF340DB8 Reserved
  0xFFFFFFFF,   // H'FF340DBC Reserved
  0xFFFFFFFF,   // H'FF340DC0 Reserved
  0xFFFFFFFF,   // H'FF340DC4 Reserved
  0xFFFFFFFF,   // H'FF340DC8 Reserved
  0xFFFFFFFF,   // H'FF340DCC Reserved
  0xFFFFFFFF,   // H'FF340DD0 Reserved
  0xFFFFFFFF,   // H'FF340DD4 Reserved
  0xFFFFFFFF,   // H'FF340DD8 Reserved
  0xFFFFFFFF,   // H'FF340DDC Reserved
  0xFFFFFFFF,   // H'FF340DE0 Reserved
  0xFFFFFFFF,   // H'FF340DE4 Reserved
  0xFFFFFFFF,   // H'FF340DE8 Reserved
  0xFFFFFFFF,   // H'FF340DEC Reserved
  0xFFFFFFFF,   // H'FF340DF0 Reserved
  0xFFFFFFFF,   // H'FF340DF4 Reserved
  0xFFFFFFFF,   // H'FF340DF8 Reserved
  0xFFFFFFFF,   // H'FF340DFC Reserved
  // cannot-write offset 600-7FF
};

*******************************************************************************************/

#pragma ghs section rodata=default
